@@ -14,6 +14,8 @@
 #include <QtCore/QStringList>
 #include <QtCore/QVariant>
 #include <QDebug>
+#include <QJsonDocument>
+#include <QJsonObject>
 
 /*
  * Implementation of adaptor class DBusScreenshotService
@@ -27,6 +29,12 @@ DBusScreenshotService::DBusScreenshotService(Screenshot *parent)
     // constructor
     Q_UNUSED(parent);
     setAutoRelaySignals(true);
+    
+    // 连接Screenshot的screenshotSaved信号到CustomDone信号
+    connect(parent, &Screenshot::screenshotSaved, this, [this](const QString &savePath) {
+        emit CustomDone(savePath);
+        qCInfo(dsrApp) << "CustomDone signal emitted with path:" << savePath;
+    });
 }
 
 DBusScreenshotService::~DBusScreenshotService()
@@ -218,3 +226,24 @@ void DBusScreenshotService::FullScreenRecord(const QString &in0)
     m_singleInstance = true;
     qCDebug(dsrApp) << "FullScreenRecord method finished.";
 }
+
+void DBusScreenshotService::CustomScreenshot(const QVariantMap &params)
+{
+    qCDebug(dsrApp) << "CustomScreenshot method called with QVariantMap parameters";
+    
+    // 解析参数
+    bool showToolbar = params.value("showToolBar", true).toBool();
+    bool showNotification = params.value("showNotification", true).toBool();
+    
+    qCDebug(dsrApp) << "Parsed parameters:" << "showToolbar:" << showToolbar << "showNotification:" << showNotification;
+    qCDebug(dsrApp) << "CustomScreenshot will emit CustomDone signal when screenshot is saved";
+    
+    if (!m_singleInstance) {
+        qCDebug(dsrApp) << "Starting new custom screenshot instance";
+        parent()->customScreenshot(showToolbar, showNotification);
+    } else {
+        qCDebug(dsrApp) << "Screenshot instance already running";
+    }
+    m_singleInstance = true;
+    qCDebug(dsrApp) << "CustomScreenshot method finished.";
+}
