@@ -10,6 +10,8 @@
 
 #include <QActionGroup>
 #include <QMouseEvent>
+#include <QTimer>
+#include "mainwindow.h"
 
 #include <DFontSizeManager>
 #include <DSysInfo>
@@ -69,10 +71,20 @@ void ToolBarWidget::showAt(QPoint pos, bool isfirstTime)
 {
     qCDebug(dsrApp) << "Showing toolbar at position:" << pos << ", isFirstTime:" << isfirstTime;
     this->move(pos);
+    
+    // 确保几何信息更新
+    this->updateGeometry();
+    this->layout()->activate();
+    
     if (this->isHidden()) {
         this->show();
         qCDebug(dsrApp) << "Toolbar was hidden, now shown.";
     }
+    
+    // 再次确保几何信息正确
+    QRect geom = this->geometry();
+    qCDebug(dsrApp) << "Toolbar geometry after showing:" << geom;
+    
     if (isfirstTime) {
         this->hide();
         qCDebug(dsrApp) << "First time showing, hiding toolbar.";
@@ -108,6 +120,7 @@ void ToolBarWidget::initToolBarWidget()
     m_subTool = new SubToolWidget(this);
     qCDebug(dsrApp) << "SubToolWidget created.";
     connect(m_subTool, SIGNAL(signalOcrButtonClicked()), this, SIGNAL(sendOcrButtonClicked()));
+    connect(m_subTool, &SubToolWidget::signalSaveToLocalButtonClicked, this, &ToolBarWidget::signalSaveToLocalButtonClicked);
     qCDebug(dsrApp) << "Connected signalOcrButtonClicked.";
 
     m_mainTool = new MainToolWidget(this);
@@ -116,6 +129,8 @@ void ToolBarWidget::initToolBarWidget()
     qCDebug(dsrApp) << "Connected signalCloseButtonClicked.";
     connect(m_mainTool, SIGNAL(signalSaveButtonClicked()), this, SIGNAL(sendSaveButtonClicked()));
     qCDebug(dsrApp) << "Connected signalSaveButtonClicked.";
+    connect(m_mainTool, SIGNAL(signalSaveToLocalButtonClicked()), this, SIGNAL(sendSaveToLocalButtonClicked()));
+    qCDebug(dsrApp) << "Connected signalSaveToLocalButtonClicked.";
 
     QHBoxLayout *hLayout = new QHBoxLayout(this);
     qCDebug(dsrApp) << "Horizontal layout created.";
@@ -124,6 +139,7 @@ void ToolBarWidget::initToolBarWidget()
     hLayout->addWidget(m_mainTool, 0,  Qt::AlignCenter);
     setLayout(hLayout);
     qCDebug(dsrApp) << "Layout set for toolbar widget.";
+    setMouseTracking(true);
 }
 
 //重写鼠标移动事件：解决工具栏可以被拖动的问题
@@ -134,3 +150,32 @@ void ToolBarWidget::mouseMoveEvent(QMouseEvent *event)
     //qDebug() << event->button() << event->x() << event->y();
     //QWidget::mouseMoveEvent(event);
 }
+
+// 确保鼠标进入工具栏时工具栏保持显示
+void ToolBarWidget::enterEvent(QEnterEvent *event)
+{
+    Q_UNUSED(event);
+    qCDebug(dsrApp) << "Mouse entered ToolBarWidget.";
+
+    MainWindow* parentWindow = qobject_cast<MainWindow*>(this->parent());
+    if (parentWindow) {
+        parentWindow->checkToolbarVisibility();
+    }
+
+    QWidget::enterEvent(event);
+}
+
+// 处理鼠标离开工具栏的情况
+void ToolBarWidget::leaveEvent(QEvent *event)
+{
+    Q_UNUSED(event);
+    qCDebug(dsrApp) << "Mouse left ToolBarWidget.";
+
+    MainWindow* parentWindow = qobject_cast<MainWindow*>(this->parent());
+    if (parentWindow) {
+        // 当鼠标离开时，我们不直接隐藏，而是让主窗口启动隐藏定时器
+        parentWindow->startToolbarHideTimer();
+    }
+
+    QWidget::leaveEvent(event);
+}
