@@ -1,5 +1,5 @@
 // Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co.,Ltd.
-// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -8,12 +8,18 @@
 
 #include <QObject>
 
+enum SaveWays : unsigned int {
+    Ask, // 每次都询问
+    SpecifyLocation // 指定位置
+};
+
 enum SaveAction : unsigned int {
     SaveToClipboard,
     SaveToDesktop,
     SaveToImage,
     SaveToSpecificDir,
     AutoSave, // 自定义保存目录
+    CustomScreenSave, // 通过dbus调用customscreen截图保存的位置
 };
 Q_DECLARE_METATYPE(SaveAction);
 #endif // SAVEUTILS_H
