@@ -10,6 +10,7 @@
 #include "../utils/baseutils.h"
 #include "../utils/configsettings.h"
 #include "../utils/saveutils.h"
+#include "../utils/log.h"
 
 #include <DSlider>
 #include <DLineEdit>
@@ -33,11 +34,13 @@ SubToolBar::SubToolBar(DWidget *parent)
     : DStackedWidget(parent),
       m_lineWidth(1)
 {
+    qCDebug(dsrApp) << "SubToolBar constructor called.";
     initWidget();
 }
 
 void SubToolBar::initWidget()
 {
+    qCDebug(dsrApp) << "SubToolBar::initWidget called.";
 //    setObjectName("SubToolBar");
 //    setStyleSheet(getFileContent(":/resources/qss/subtoolbar.qss"));
     setFixedSize(TOOLBAR_WIDTH, TOOLBAR_HEIGHT);
@@ -54,6 +57,7 @@ void SubToolBar::initWidget()
 
 void SubToolBar::initRectLabel()
 {
+    qCDebug(dsrApp) << "SubToolBar::initRectLabel called.";
     m_rectLabel = new DLabel(this);
     QButtonGroup *rectBtnGroup = new QButtonGroup();
     rectBtnGroup->setExclusive(true);
@@ -81,17 +85,21 @@ void SubToolBar::initRectLabel()
     ToolButton *mosaicBtn = new ToolButton();
     mosaicBtn->setObjectName("MosaicBtn");
     connect(blurBtn, &ToolButton::clicked, this, [ = ] {
+        qCDebug(dsrApp) << "Blur button clicked.";
         ConfigSettings::instance()->setValue("effect", "is_blur", blurBtn->isChecked());
         if (blurBtn->isChecked())
         {
+            qCDebug(dsrApp) << "Blur button checked, unchecking mosaic.";
             mosaicBtn->setChecked(false);
             ConfigSettings::instance()->setValue("effect", "is_mosaic", false);
         }
     });
     connect(mosaicBtn, &ToolButton::clicked, this, [ = ] {
+        qCDebug(dsrApp) << "Mosaic button clicked.";
         ConfigSettings::instance()->setValue("effect", "is_mosaic", mosaicBtn->isChecked());
         if (mosaicBtn->isChecked())
         {
+            qCDebug(dsrApp) << "Mosaic button checked, unchecking blur.";
             blurBtn->setChecked(false);
             ConfigSettings::instance()->setValue("effect", "is_blur", false);
         }
@@ -99,6 +107,7 @@ void SubToolBar::initRectLabel()
     int lineWidthIndex = ConfigSettings::instance()->value("rectangle",
                                                            "linewidth_index").toInt();
     btnList[lineWidthIndex]->setChecked(true);
+    qCDebug(dsrApp) << "Initial line width index for rectangle:" << lineWidthIndex;
 
     QHBoxLayout *rectLayout = new QHBoxLayout();
     rectLayout->setContentsMargins(0, 0, 0, 0);
@@ -108,6 +117,7 @@ void SubToolBar::initRectLabel()
         rectLayout->addWidget(btnList[i]);
         rectLayout->addSpacing(BUTTON_SPACING);
         connect(btnList[i], &ToolButton::clicked, this, [ = ] {
+            qCDebug(dsrApp) << "Line thickness button clicked, index:" << i;
             ConfigSettings::instance()->setValue(m_currentType, "linewidth_index", i);
         });
     }
@@ -122,14 +132,17 @@ void SubToolBar::initRectLabel()
     addWidget(m_rectLabel);
 
     connect(this, &SubToolBar::shapeChanged, this, [ = ] {
+        qCDebug(dsrApp) << "Shape changed signal received in initRectLabel.";
         int lineIndex = ConfigSettings::instance()->value(m_currentType,
                                                           "linewidth_index").toInt();
         btnList[lineIndex]->setChecked(true);
+        qCDebug(dsrApp) << "Setting line width based on shape change to index:" << lineIndex;
     });
 }
 
 void SubToolBar::initArrowLabel()
 {
+    qCDebug(dsrApp) << "SubToolBar::initArrowLabel called.";
     m_arrowLabel = new DLabel(this);
     //arrow
     QButtonGroup  *arrowBtnGroup = new QButtonGroup();
@@ -177,13 +190,16 @@ void SubToolBar::initArrowLabel()
     arrowBtn->setChecked(true);
     styleBtnGroup->addButton(arrowBtn, 1);
     if (ConfigSettings::instance()->value("arrow", "is_straight").toBool()) {
+        qCDebug(dsrApp) << "Initial state: straight line button checked.";
         lineBtn->setChecked(true);
     } else {
+        qCDebug(dsrApp) << "Initial state: arrow button checked.";
         arrowBtn->setChecked(true);
     }
 
     int arrowWidthIndex = ConfigSettings::instance()->value("arrow", "arrow_linewidth_index").toInt();
     int sLineWidthIndex = ConfigSettings::instance()->value("arrow", "straightline_linewidth").toInt();
+    qCDebug(dsrApp) << "Initial arrow width index:" << arrowWidthIndex << ", straight line width index:" << sLineWidthIndex;
     arrowBtnList[arrowWidthIndex]->setChecked(true);
     arrowBtnList[sLineWidthIndex + 3]->setChecked(true);
     QHBoxLayout *arrowLayout = new QHBoxLayout();
@@ -194,11 +210,14 @@ void SubToolBar::initArrowLabel()
         arrowLayout->addWidget(arrowBtnList[j]);
 //        arrowLayout->addSpacing(BUTTON_SPACING);
         connect(arrowBtnList[j], &ToolButton::clicked, this, [ = ] {
+            qCDebug(dsrApp) << "Arrow/line thickness button clicked, index:" << j;
             if (j < 3)
             {
+                qCDebug(dsrApp) << "Setting arrow line width index:" << j;
                 ConfigSettings::instance()->setValue("arrow", "arrow_linewidth_index", j);
             } else
             {
+                qCDebug(dsrApp) << "Setting straight line width index:" << j - 3;
                 ConfigSettings::instance()->setValue("arrow", "straightline_linewidth_index", j - 3);
             }
         });
@@ -217,7 +236,9 @@ void SubToolBar::initArrowLabel()
     thickLine->hide();
 
     connect(arrowBtn, &ToolButton::toggled, this, [ = ](bool checked) {
+        qCDebug(dsrApp) << "Arrow button toggled, checked:" << checked;
         if (checked) {
+            qCDebug(dsrApp) << "Arrow button checked, showing arrow line options.";
             arrowFineLine->show();
             arrowMediumLine->show();
             arrowThickLine->show();
@@ -225,6 +246,7 @@ void SubToolBar::initArrowLabel()
             mediumLine->hide();
             thickLine->hide();
         } else {
+            qCDebug(dsrApp) << "Arrow button unchecked, showing straight line options.";
             arrowFineLine->hide();
             arrowMediumLine->hide();
             arrowThickLine->hide();
@@ -237,8 +259,10 @@ void SubToolBar::initArrowLabel()
     });
 
     connect(this, &SubToolBar::shapeChanged, this, [ = ] {
+        qCDebug(dsrApp) << "Shape changed signal received in initArrowLabel.";
         if (ConfigSettings::instance()->value("arrow", "is_straight").toBool())
         {
+            qCDebug(dsrApp) << "Shape changed to straight line, showing straight line options.";
             arrowFineLine->hide();
             arrowMediumLine->hide();
             arrowThickLine->hide();
@@ -247,6 +271,7 @@ void SubToolBar::initArrowLabel()
             thickLine->show();
         } else
         {
+            qCDebug(dsrApp) << "Shape changed to arrow, showing arrow line options.";
             arrowFineLine->show();
             arrowMediumLine->show();
             arrowThickLine->show();
@@ -264,6 +289,7 @@ void SubToolBar::initArrowLabel()
 
 void SubToolBar::initLineLabel()
 {
+    qCDebug(dsrApp) << "SubToolBar::initLineLabel called.";
     m_lineLabel = new DLabel(this);
     //rectangle, oval...
     QButtonGroup *lineBtnGroup = new QButtonGroup();
@@ -286,6 +312,7 @@ void SubToolBar::initLineLabel()
     int lineWidthIndex = ConfigSettings::instance()->value("line",
                                                            "linewidth_index").toInt();
     btnList[lineWidthIndex]->setChecked(true);
+    qCDebug(dsrApp) << "Initial line width index for line:" << lineWidthIndex;
 
     QHBoxLayout *lineLayout = new QHBoxLayout();
     lineLayout->setContentsMargins(0, 0, 0, 0);
@@ -295,6 +322,7 @@ void SubToolBar::initLineLabel()
         lineLayout->addWidget(btnList[k]);
         lineLayout->addSpacing(BUTTON_SPACING);
         connect(btnList[k], &ToolButton::clicked, this, [ = ] {
+            qCDebug(dsrApp) << "Line thickness button clicked for line, index:" << k;
             ConfigSettings::instance()->setValue("line", "linewidth_index", k);
         });
     }
@@ -304,14 +332,17 @@ void SubToolBar::initLineLabel()
     addWidget(m_lineLabel);
 
     connect(this, &SubToolBar::shapeChanged, this, [ = ] {
+        qCDebug(dsrApp) << "Shape changed signal received in initLineLabel.";
         int lineIndex = ConfigSettings::instance()->value(m_currentType,
                                                           "linewidth_index").toInt();
         btnList[lineIndex]->setChecked(true);
+        qCDebug(dsrApp) << "Setting line width based on shape change for line to index:" << lineIndex;
     });
 }
 
 void SubToolBar::initTextLabel()
 {
+    qCDebug(dsrApp) << "SubToolBar::initTextLabel called.";
     //text...
     m_textLabel = new DLabel(this);
 //    m_textLabel->setStyleSheet(getFileContent(":/resources/qss/textbutton.qss"));
@@ -327,6 +358,7 @@ void SubToolBar::initTextLabel()
     }
     textBtnGroup->setExclusive(true);
     int defaultFontSize = ConfigSettings::instance()->value("text", "fontsize").toInt();
+    qCDebug(dsrApp) << "Default font size:" << defaultFontSize;
 
     QHBoxLayout *textLayout = new QHBoxLayout();
     textLayout->setContentsMargins(0, 0, 0, 0);
@@ -336,6 +368,7 @@ void SubToolBar::initTextLabel()
         textLayout->addWidget(textButtonList[k]);
         textLayout->addSpacing(BUTTON_SPACING);
         if (fontSizeList[k] == defaultFontSize) {
+            qCDebug(dsrApp) << "Setting text button checked for font size:" << fontSizeList[k];
             textButtonList[k]->setChecked(true);
         }
     }
@@ -346,6 +379,7 @@ void SubToolBar::initTextLabel()
 
 void SubToolBar::initColorLabel()
 {
+    qCDebug(dsrApp) << "SubToolBar::initColorLabel called.";
     m_colorLabel = new DLabel(this);
 //    m_colorLabel->setStyleSheet(getFileContent(":/resources/qss/colorbtn.qss"));
     QList<ColorButton *> colorBtnList;
@@ -357,6 +391,7 @@ void SubToolBar::initColorLabel()
         colorBtn->setObjectName(QString("ColorBtn%1").arg(i + 1));
         colorBtnList.append(colorBtn);
         colorBtnGroup->addButton(colorBtn);
+        qCDebug(dsrApp) << "Adding color button for index:" << i;
     }
 
     QHBoxLayout *colorLayout = new QHBoxLayout();
@@ -368,6 +403,7 @@ void SubToolBar::initColorLabel()
         colorLayout->addSpacing(1);
         connect(colorBtnList[i], &ColorButton::updatePaintColor,
                 this, &SubToolBar::updateColor);
+        qCDebug(dsrApp) << "Connecting updatePaintColor for color button:" << i;
     }
     colorLayout->addStretch();
     m_colorLabel->setLayout(colorLayout);
@@ -375,20 +411,24 @@ void SubToolBar::initColorLabel()
     addWidget(m_colorLabel);
 
     connect(this, &SubToolBar::defaultColorIndexChanged, this, [ = ](int index) {
+        qCDebug(dsrApp) << "Default color index changed to:" << index;
         colorBtnList[index]->setChecked(true);
     });
 }
 
 void SubToolBar::updateColor(QColor color)
 {
+    qCDebug(dsrApp) << "SubToolBar::updateColor called with color:" << color;
 //    qDebug() << "update text color";
     int colNum = colorIndex(color);
+    qCDebug(dsrApp) << "Calculated color number:" << colNum;
     ConfigSettings::instance()->setValue("common", "color_index", colNum);
     emit currentColorChanged(color);
 }
 
 void SubToolBar::initSaveLabel()
 {
+    qCDebug(dsrApp) << "SubToolBar::initSaveLabel called.";
     //save to...
     std::map<SaveAction, ToolButton *> toolBtnMap;
     ToolButton *saveDesktopBtn = new ToolButton();
@@ -445,6 +485,7 @@ void SubToolBar::initSaveLabel()
     saveLayout->addSpacing(1);
 
     SaveAction saveAction = ConfigSettings::instance()->value("save", "save_op").value<SaveAction>();
+    qCDebug(dsrApp) << "Initial save action:" << static_cast<int>(saveAction);
 
     for (auto it = toolBtnMap.cbegin(); it != toolBtnMap.cend(); ++it) {
         SaveAction  action = it->first;
@@ -453,27 +494,33 @@ void SubToolBar::initSaveLabel()
         saveLayout->addWidget(button);
 
         connect(button, &ToolButton::clicked, this, [ = ] {
+            qCDebug(dsrApp) << "Save option button clicked, action:" << static_cast<int>(action);
             setSaveOption(action);
         });
 
         connect(button, &ToolButton::onEnter, this, [ = ] {
+            qCDebug(dsrApp) << "Show save tip for button:" << button->objectName();
             emit showSaveTip(button->getTips());
         });
 
         connect(button, &ToolButton::onExist, this, &SubToolBar::hideSaveTip);
 
         if (saveAction == action) {
+            qCDebug(dsrApp) << "Setting save action button checked for action:" << static_cast<int>(action);
             button->setChecked(true);
         }
     }
 
     connect(this, &SubToolBar::saveBtnPressed, this, [ = ](int index) -> void {
+        qCDebug(dsrApp) << "Save button pressed with index:" << index;
         for (auto it = toolBtnMap.cbegin(); it != toolBtnMap.cend(); ++it)
         {
             if (static_cast<SaveAction>(index) == it->first) {
+                qCDebug(dsrApp) << "Clicking save button for action:" << static_cast<int>(it->first);
                 return it->second->click();
             }
         }
+        qCDebug(dsrApp) << "No matching save action found for index:" << index;
     });
 
     saveLayout->addStretch();
@@ -484,32 +531,40 @@ void SubToolBar::initSaveLabel()
 
     m_saveLabel->setLayout(saveLayout);
     addWidget(m_saveLabel);
+    qDebug() << "SubToolBar::initSaveLabel called.";
 }
 
 void SubToolBar::switchContent(QString shapeType)
 {
+    qDebug() << "SubToolBar::switchContent called with shapeType:" << shapeType;
     if (shapeType == "rectangle" || shapeType == "oval") {
+        qDebug() << "Switching to rectangle or oval content.";
         setCurrentWidget(m_rectLabel);
         m_currentType = shapeType;
         emit shapeChanged();
     }   else if (shapeType == "arrow") {
+        qDebug() << "Switching to arrow content.";
         setCurrentWidget(m_arrowLabel);
         m_currentType = shapeType;
         emit shapeChanged();
     } else if (shapeType == "line") {
+        qDebug() << "Switching to line content.";
         setCurrentWidget(m_lineLabel);
         m_currentType = shapeType;
         emit shapeChanged();
     } else if (shapeType == "text") {
+        qDebug() << "Switching to text content.";
         setCurrentWidget(m_textLabel);
         m_currentType = shapeType;
         emit shapeChanged();
     } else if (shapeType == "color") {
+        qDebug() << "Switching to color content.";
         int defaultColorIndex = ConfigSettings::instance()->value("common",
                                                                   "color_index").toInt();
         emit defaultColorIndexChanged(defaultColorIndex);
         setCurrentWidget(m_colorLabel);
     } else if (shapeType == "saveList") {
+        qDebug() << "Switching to saveList content.";
         setCurrentWidget(m_saveLabel);
     }
     qDebug() << "subToolBar shape:" << shapeType;
@@ -517,6 +572,7 @@ void SubToolBar::switchContent(QString shapeType)
 
 void SubToolBar::setSaveOption(SaveAction action)
 {
+    qCDebug(dsrApp) << "SubToolBar::setSaveOption called with action:" << static_cast<int>(action);
     if (QGuiApplication::keyboardModifiers().testFlag(Qt::ShiftModifier)) {
         qDebug() << "Shift key holded: temporary action, will not remember the save_op.";
         ConfigSettings::instance()->setTemporarySaveAction(std::pair<bool, SaveAction>(true, action));
@@ -529,6 +585,7 @@ void SubToolBar::setSaveOption(SaveAction action)
 
 void SubToolBar::setSaveQualityIndex(int saveQuality)
 {
+    qCDebug(dsrApp) << "SubToolBar::setSaveQualityIndex called with quality:" << saveQuality;
     ConfigSettings::instance()->setValue("save", "save_quality", saveQuality);
 }
 /*
