@@ -25,6 +25,17 @@ or press the shortcut again to stop recording</source>
         <translation>བརྙན་ཕབ།</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>ཁ་རྒྱག་(Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>ཁ་རྒྱག་(Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ or press the shortcut again to stop recording</source>
         <translation>ཕྱིར་འཐེན།</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>དུ་ཉར་བ།</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>དུ་ཉར་བ།</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>ཉར་སྐབས་གནས་ས་སྒྲིག་འགོད་བྱེད་པ། </translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>ཉར་སྐབས་གནས་ས་གསར་སྒྱུར་བྱེད་པ།</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ or press the shortcut again to stop recording</source>
         <translation>ཡིག་ཁུག་ཁ་ཕྱེ།</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>དུ་ཉར་བ།</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation></translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Shiftམནན་ནས་ཐད་དཔྱང་དང་ཆུ་སྙོམ
         <source>Record</source>
         <translation>བརྙན་ཕབ།</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>པར་རིས།</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>ཉར་སྐབས་གནས་ས་སྒྲིག་འགོད་བྱེད་པ། </translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>ཉར་སྐབས་གནས་ས་གསར་སྒྱུར་བྱེད་པ།</translation>
@@ -658,14 +699,6 @@ Shiftམནན་ནས་གྲུ་བཞི་ཁ་གང་འབྲི་
         <source>Save to local</source>
         <translation>དུ་ཉར་བ།</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>ཅོག་ངོས།</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>པར་རིས།</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>དུ་ཉར་བ།</translation>
@@ -675,24 +708,12 @@ Shiftམནན་ནས་གྲུ་བཞི་ཁ་གང་འབྲི་
         <translation>དུ་ཉར་བ།</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>དུ་ཉར་བ།</translation>
+        <source>Update the location when saving</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>དུ་ཉར་བ།</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>དུ་ཉར་བ།</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>ཅོག་ངོས།</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>པར་རིས།</translation>
+        <source>Select a location when saving</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Shiftམནན་ནས་གྲུ་བཞི་ཁ་གང་འབྲི་
         <source>Copy to clipboard (Enter)</source>
         <translation>ཁ་རྒྱག་(Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>ཁ་རྒྱག་(Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
