@@ -25,6 +25,17 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <translation>التسجيل</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>إغلاق (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>نسخ إلى الحافظة (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <translation>Kuitaat</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>كل سؤال</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>موقع محدد</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>تحديد مسار عند الحفظ</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>تغيير المسار عند الحفظ</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ pe bouezit adarre war ar verradenn evit paouez an enrolladenn</translation>
         <translation>فتح المجلد</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>كل سؤال</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation></translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <source>Record</source>
         <translation>Enrollañ</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Skeudennoù</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>تحديد مسار عند الحفظ</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>تغيير المسار عند الحفظ</translation>
@@ -657,14 +698,6 @@ Hold down Shift to draw squares or circles.</source>
         <source>Save to local</source>
         <translation>حفظ إلى الموقع المحلي</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>حفظ إلى المكتب</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>حفظ إلى الصور</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>حفظ إلى %1</translation>
@@ -674,24 +707,12 @@ Hold down Shift to draw squares or circles.</source>
         <translation>موقع محدد</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>موقع مخصص</translation>
+        <source>Update the location when saving</source>
+        <translation></translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>كل سؤال</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>تحديث الموقع عند الحفظ</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>حفظ إلى المكتب</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>حفظ إلى الصور</translation>
+        <source>Select a location when saving</source>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -704,6 +725,10 @@ Hold down Shift to draw squares or circles.</source>
         <source>Copy to clipboard (Enter)</source>
         <translation>نسخ إلى الحافظة (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>موافق (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
