@@ -25,6 +25,17 @@ o premeu la drecera de nou per aturar la gravació.</translation>
         <translation>Gavació</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Tanca (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Copia a la porta-retalls (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ o premeu la drecera de nou per aturar la gravació.</translation>
         <translation>Surt</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Cada pregunta</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Ubicació especificada</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Estableix un camí per desar</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Canvia el camí per desar</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ o premeu la drecera de nou per aturar la gravació.</translation>
         <translation>Obre la carpeta</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Cada pregunta</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Ubicació especificada</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Selecciona una ubicació quan es desa</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Actualitza la ubicació quan es desa</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Manteniu premuda la tecla Maj per dibuixar una fletxa vertical o horitzontal.</t
         <source>Record</source>
         <translation>Grava</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Fotos</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Estableix un camí per desar</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Canvia el camí per desar</translation>
@@ -657,14 +698,6 @@ Hold down Shift to draw squares or circles.</source>
         <source>Save to local</source>
         <translation>Desa a local</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Desa a l&apos;escriptori</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Desa a fotos</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Desa a %1</translation>
@@ -674,24 +707,12 @@ Hold down Shift to draw squares or circles.</source>
         <translation>Ubicació especificada</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Ubicació personalitzada</translation>
+        <source>Update the location when saving</source>
+        <translation>Actualitza la ubicació quan es desa</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Cada pregunta</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Actualitza la ubicació al desar</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Desa a l&apos;escriptori</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Desa a fotos</translation>
+        <source>Select a location when saving</source>
+        <translation>Selecciona una ubicació quan es desa</translation>
     </message>
 </context>
 <context>
@@ -704,6 +725,10 @@ Hold down Shift to draw squares or circles.</source>
         <source>Copy to clipboard (Enter)</source>
         <translation>Copia a la porta-retalls (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
