@@ -25,6 +25,17 @@ v oznamovací oblasti panelu nebo stiskněte klávesovou zkratku</translation>
         <translation>Nahrávání</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Zavřít (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Vložit do schránky (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ v oznamovací oblasti panelu nebo stiskněte klávesovou zkratku</translation>
         <translation>Ukončit</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Každá otázka</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Určené umístění</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Nastavit popis umístění při ukládání</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Změnit popis umístění pro ukládání</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ v oznamovací oblasti panelu nebo stiskněte klávesovou zkratku</translation>
         <translation>Otevřít složku</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Každá otázka</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Určené umístění</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Vybrat umístění při ukládání</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Aktualizovat umístění při ukládání</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Stiskněte a podržte klávesu Shift pro kreslení svislé nebo vodorovné šipk
         <source>Record</source>
         <translation>Pořídit záznam</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Obrázky</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Nastavit popis umístění při ukládání</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Změnit popis umístění pro ukládání</translation>
@@ -657,14 +698,6 @@ Hold down Shift to draw squares or circles.</source>
         <source>Save to local</source>
         <translation>Uložit do místního</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Uložit do plochy</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Uložit do obrázků</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Uložit do %1</translation>
@@ -674,24 +707,12 @@ Hold down Shift to draw squares or circles.</source>
         <translation>Určené umístění</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Vlastní umístění</translation>
-    </message>
-    <message>
-        <source>Each inquiry</source>
-        <translation>Každá otázka</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
+        <source>Update the location when saving</source>
         <translation>Aktualizovat umístění při ukládání</translation>
     </message>
     <message>
-        <source>Save to desktop</source>
-        <translation>Uložit do plochy</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Uložit do obrázků</translation>
+        <source>Select a location when saving</source>
+        <translation>Vybrat umístění při ukládání</translation>
     </message>
 </context>
 <context>
@@ -704,6 +725,10 @@ Hold down Shift to draw squares or circles.</source>
         <source>Copy to clipboard (Enter)</source>
         <translation>Vložit do schránky (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
