@@ -25,6 +25,17 @@ eller tryk på genvejen igen, for at stoppe optagelse</translation>
         <translation>Optagelse</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Luk (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Kopier til udklipsholder (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ eller tryk på genvejen igen, for at stoppe optagelse</translation>
         <translation>Afslut</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Hver spørgsmål</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation type="unfinished">Angivet sted</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation type="unfinished">Angiv en mappe ved opbevaring</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation type="unfinished">Ændr stien ved opbevaring</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ eller tryk på genvejen igen, for at stoppe optagelse</translation>
         <translation>Åbn mappe</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation type="unfinished">Hver spørgsmål</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Angivet sted</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Vælg et sted ved opbevaring</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Opdateret sted ved opbevaring</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Tryk og hold Shift for at tegne en vertikal eller horisontal pil</translation>
         <source>Record</source>
         <translation>Optag</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Billeder</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Angiv en mappe ved opbevaring</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Ændr stien ved opbevaring</translation>
@@ -658,14 +699,6 @@ Hold Shift nede for at tegne kvadrater eller cirkler.</translation>
         <source>Save to local</source>
         <translation>Gem til lokal</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Gem til skrivebord</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Gem til billeder</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Gem til %1</translation>
@@ -675,24 +708,12 @@ Hold Shift nede for at tegne kvadrater eller cirkler.</translation>
         <translation>Angivet sted</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Tilpasset sted</translation>
+        <source>Update the location when saving</source>
+        <translation>Opdateret sted ved opbevaring</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Hver spørgsmål</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Opdater sted ved gemning</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Gem til skrivebord</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Gem til billeder</translation>
+        <source>Select a location when saving</source>
+        <translation>Vælg et sted ved opbevaring</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Hold Shift nede for at tegne kvadrater eller cirkler.</translation>
         <source>Copy to clipboard (Enter)</source>
         <translation>Kopier til udklipsholder (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
