@@ -25,6 +25,17 @@ oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</tran
         <translation>Wird aufgenommen</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Schließen (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>In die Zwischenablage kopieren (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</tran
         <translation>Beenden</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Jede Frage</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Ange Ort</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Beim Speichern einen Pfad festlegen</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Beim Speichern den Pfad ändern</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</tran
         <translation>Ordner öffnen</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Jede Frage</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Ange Ort</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Beim Speichern einen Pfad festlegen</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Beim Speichern den Pfad ändern</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Umschalttaste gedrückt halten, um einen vertikalen oder horizontalen Pfeil zu z
         <source>Record</source>
         <translation>Aufnehmen</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Bilder</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Beim Speichern einen Pfad festlegen</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Beim Speichern den Pfad ändern</translation>
@@ -658,14 +699,6 @@ Halten Sie die Umschalttaste gedrückt, um Quadrate oder Kreise zu zeichnen.</tr
         <source>Save to local</source>
         <translation>Lokal speichern</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Auf das Desktop-Verzeichnis speichern</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Auf das Bildverzeichnis speichern</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Auf %1 speichern</translation>
@@ -675,24 +708,12 @@ Halten Sie die Umschalttaste gedrückt, um Quadrate oder Kreise zu zeichnen.</tr
         <translation>Ange Ort</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Benutzerdefiniertes Ort</translation>
+        <source>Update the location when saving</source>
+        <translation>Beim Speichern den Pfad ändern</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Jede Frage</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Ort beim Speichern aktualisieren</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Auf das Desktop-Verzeichnis speichern</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Auf das Bildverzeichnis speichern</translation>
+        <source>Select a location when saving</source>
+        <translation>Beim Speichern einen Pfad festlegen</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Halten Sie die Umschalttaste gedrückt, um Quadrate oder Kreise zu zeichnen.</tr
         <source>Copy to clipboard (Enter)</source>
         <translation>In die Zwischenablage kopieren (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
