@@ -25,6 +25,17 @@ or press the shortcut again to stop recording</translation>
         <translation>Recording</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Close (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Copy to clipboard (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ or press the shortcut again to stop recording</translation>
         <translation>Exit</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Each inquiry</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Specified Location</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Set a path on save</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Change the path on save</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ or press the shortcut again to stop recording</translation>
         <translation>Open Folder</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Each inquiry</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Specified location</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Select a location when saving</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Update the location when saving</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -448,10 +497,6 @@ Press and hold Shift to draw a straight line</translation>
         <source>Options</source>
         <translation>Options</translation>
     </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Set a path on save</translation>
-    </message>
     <message>
         <source>Save to</source>
         <translation>Save to</translation>
@@ -460,10 +505,6 @@ Press and hold Shift to draw a straight line</translation>
         <source>Desktop</source>
         <translation>Desktop</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Pictures</translation>
-    </message>
     <message>
         <source>Format</source>
         <translation>Format</translation>
@@ -658,14 +699,6 @@ Hold down Shift to draw squares or circles.</translation>
         <source>Save to local</source>
         <translation>Save to local</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Save to Desktop</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Save to Pictures</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Save to %1</translation>
@@ -675,24 +708,12 @@ Hold down Shift to draw squares or circles.</translation>
         <translation>Specified Location</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Custom Location</translation>
+        <source>Update the location when saving</source>
+        <translation>Update the location when saving</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Each inquiry</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Update location on save</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Save to desktop</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Save to pictures</translation>
+        <source>Select a location when saving</source>
+        <translation>Select a location when saving</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Hold down Shift to draw squares or circles.</translation>
         <source>Copy to clipboard (Enter)</source>
         <translation>Copy to clipboard (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
