@@ -25,6 +25,17 @@ o haga clic en el icono de la bandeja</translation>
         <translation>Grabaciones</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Cerrar (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Copiar al portapapeles (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ o haga clic en el icono de la bandeja</translation>
         <translation>Salir</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Cada consulta</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Ubicación especificada</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Establecer ruta para guardar</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Cambiar ruta de guardado</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ o haga clic en el icono de la bandeja</translation>
         <translation>Abrir carpeta</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Cada consulta</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Ubicación especificada</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Seleccionar una ubicación al guardar</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Actualizar la ubicación al guardar</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Mantenga presionada la tecla Mayús para dibujar una flecha vertical u horizonta
         <source>Record</source>
         <translation>Grabación</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Imágenes</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Establecer ruta para guardar</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Cambiar ruta de guardado</translation>
@@ -658,14 +699,6 @@ Mantenga presionada la tecla Shift para dibujar cuadrados o círculos.</translat
         <source>Save to local</source>
         <translation>Guardar en local</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Guardar en escritorio</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Guardar en imágenes</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Guardar en %1</translation>
@@ -675,24 +708,12 @@ Mantenga presionada la tecla Shift para dibujar cuadrados o círculos.</translat
         <translation>Ubicación especificada</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Ubicación personalizada</translation>
+        <source>Update the location when saving</source>
+        <translation>Actualizar la ubicación al guardar</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Cada consulta</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Actualizar ubicación al guardar</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Guardar en escritorio</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Guardar en imágenes</translation>
+        <source>Select a location when saving</source>
+        <translation>Seleccionar una ubicación al guardar</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Mantenga presionada la tecla Shift para dibujar cuadrados o círculos.</translat
         <source>Copy to clipboard (Enter)</source>
         <translation>Copiar al portapapeles (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
