@@ -25,6 +25,17 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <translation>Tallennus</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Sulje (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Kopioi leikepöydälle (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <translation>Poistu</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Jokainen kysely</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Määritetty sijainti</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Aseta tallennuspolku</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Muuta polkua tallentaessa</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ tai lopeta tallennus painamalla pikakuvaketta uudelleen</translation>
         <translation>Avaa kansio</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Jokainen kysely</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Määritetty sijainti</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Valitse sijainti tallentaessa</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Päivitä sijainti tallentaessa</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Vedä suora pysty- tai vaakanuoli pitämällä Shift-painettuna</translation>
         <source>Record</source>
         <translation>Tallenna</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Kuvat</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Aseta tallennuspolku</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Muuta polkua tallentaessa</translation>
@@ -658,14 +699,6 @@ Pidä Shift-näppäintä painettuna piirtääksesi neliöitä tai ympyröitä.</
         <source>Save to local</source>
         <translation>Tallenna paikallisesti</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Tallenna työpöydälle</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Tallenna kuvakkeisiin</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Tallenna nimellä %1</translation>
@@ -675,24 +708,12 @@ Pidä Shift-näppäintä painettuna piirtääksesi neliöitä tai ympyröitä.</
         <translation>Määritetty sijainti</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Mukautettu sijainti</translation>
+        <source>Update the location when saving</source>
+        <translation>Päivitä sijainti tallentaessa</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Jokainen kysely</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Päivitä sijainti tallessa</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Tallenna työpöydälle</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Tallenna kuvakkeisiin</translation>
+        <source>Select a location when saving</source>
+        <translation>Valitse sijainti tallentaessa</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Pidä Shift-näppäintä painettuna piirtääksesi neliöitä tai ympyröitä.</
         <source>Copy to clipboard (Enter)</source>
         <translation>Kopioi leikepöydälle (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
