@@ -25,6 +25,17 @@ ou appuyer à nouveau sur le raccourci pour arrêter l&apos;enregistrement</tran
         <translation>Enregistrement</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Fermer (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Copier dans le presse-papiers (Entrée)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ ou appuyer à nouveau sur le raccourci pour arrêter l&apos;enregistrement</tran
         <translation>Quitter</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Chaque demande</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Emplacement spécifié</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Définir un chemin d&apos;enregistrement</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Changer le chemin d&apos;enregistrement</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ ou appuyer à nouveau sur le raccourci pour arrêter l&apos;enregistrement</tran
         <translation>Ouvrir un dossier</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Chaque demande</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Emplacement spécifié</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Sélectionner un emplacement lors de l&apos;enregistrement</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Mettre à jour l&apos;emplacement lors de l&apos;enregistrement</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Maintenir la touche Maj enfoncée pour dessiner une flèche verticale ou horizon
         <source>Record</source>
         <translation>Enregistrer</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Images</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Définir un chemin d&apos;enregistrement</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Changer le chemin d&apos;enregistrement</translation>
@@ -658,14 +699,6 @@ Maintenir la touche Maj enfoncée pour dessiner des carrés ou des cercles.</tra
         <source>Save to local</source>
         <translation>Enregistrer localement</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Enregistrer sur le bureau</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Enregistrer dans les images</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Enregistrer dans %1</translation>
@@ -675,24 +708,12 @@ Maintenir la touche Maj enfoncée pour dessiner des carrés ou des cercles.</tra
         <translation>Emplacement spécifié</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Emplacement personnalisé</translation>
-    </message>
-    <message>
-        <source>Each inquiry</source>
-        <translation>Chaque demande</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
+        <source>Update the location when saving</source>
         <translation>Mettre à jour l&apos;emplacement lors de l&apos;enregistrement</translation>
     </message>
     <message>
-        <source>Save to desktop</source>
-        <translation>Enregistrer sur le bureau</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Enregistrer dans les images</translation>
+        <source>Select a location when saving</source>
+        <translation>Sélectionner un emplacement lors de l&apos;enregistrement</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Maintenir la touche Maj enfoncée pour dessiner des carrés ou des cercles.</tra
         <source>Copy to clipboard (Enter)</source>
         <translation>Copier dans le presse-papiers (Entrée)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
