@@ -25,6 +25,17 @@ ou prema de novo o atallo para deixar de gravar</translation>
         <translation>Gravando</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Pechar (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Copiar ao portapapeis (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ ou prema de novo o atallo para deixar de gravar</translation>
         <translation>Saír</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Cada consulta</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Localización especificada</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Establece un camiño ao gardar</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Cambia o camiño ao gardar</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ ou prema de novo o atallo para deixar de gravar</translation>
         <translation>Abrir cartafol</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Cada consulta</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Localización especificada</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Selecciona unha localización ao gardar</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Actualiza a localización ao gardar</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Manteña premida a tecla Maiúsculas para debuxar unha frecha vertical ou horizo
         <source>Record</source>
         <translation>Gravar</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Imaxes</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Establece un camiño ao gardar</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Cambia o camiño ao gardar</translation>
@@ -658,14 +699,6 @@ Mantén premida a tecla Maiús para debuxar cadrados ou círculos.</translation>
         <source>Save to local</source>
         <translation>Gardar no local</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Gardar no escritorio</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Gardar en imaxes</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Gardar en %1</translation>
@@ -675,24 +708,12 @@ Mantén premida a tecla Maiús para debuxar cadrados ou círculos.</translation>
         <translation>Localización especificada</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Localización personalizada</translation>
+        <source>Update the location when saving</source>
+        <translation>Actualiza a localización ao gardar</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Cada consulta</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Actualizar a localización ao gardar</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Gardar no escritorio</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Gardar en imaxes</translation>
+        <source>Select a location when saving</source>
+        <translation>Selecciona unha localización ao gardar</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Mantén premida a tecla Maiús para debuxar cadrados ou círculos.</translation>
         <source>Copy to clipboard (Enter)</source>
         <translation>Copiar ao portapapeis (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
