@@ -25,6 +25,17 @@ vagy nyomja le a gyorsbillentyűt ismét a felvétel megállításához</transla
         <translation>Rögzítés</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Bezárás (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Másolás a vágólapra (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ vagy nyomja le a gyorsbillentyűt ismét a felvétel megállításához</transla
         <translation>Kilépés</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Minden kérés</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Megadott hely</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Állítson be egy elérési utat a mentéshez</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Mentéskor módosítsa az elérési utat</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ vagy nyomja le a gyorsbillentyűt ismét a felvétel megállításához</transla
         <translation>Mappa megnyitása</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Minden kérés</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Megadott hely</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Állítson be egy elérési utat a mentéshez</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Mentéskor módosítsa az elérési utat</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Függőleges vagy vízszintes nyíl rajzolásához tartsa lenyomva a Shift bille
         <source>Record</source>
         <translation>Felvétel</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Képek</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Állítson be egy elérési utat a mentéshez</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Mentéskor módosítsa az elérési utat</translation>
@@ -658,14 +699,6 @@ Tartsa lenyomva a Shift billentyűt négyzetek vagy körök rajzolásához.</tra
         <source>Save to local</source>
         <translation>Mentés helyi könyvtárba</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Mentés asztalra</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Mentés képekhez</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Mentés ide: %1</translation>
@@ -675,24 +708,12 @@ Tartsa lenyomva a Shift billentyűt négyzetek vagy körök rajzolásához.</tra
         <translation>Megadott hely</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Egyedi hely</translation>
+        <source>Update the location when saving</source>
+        <translation>Mentéskor módosítsa az elérési utat</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Minden kérés</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Mentéskor frissítse a helyet</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Mentés asztalra</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Mentés képekhez</translation>
+        <source>Select a location when saving</source>
+        <translation>Állítson be egy elérési utat a mentéshez</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Tartsa lenyomva a Shift billentyűt négyzetek vagy körök rajzolásához.</tra
         <source>Copy to clipboard (Enter)</source>
         <translation>Másolás a vágólapra (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
