@@ -25,6 +25,17 @@ o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione<
         <translation>Registrazione in corso</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Chiudi (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Copia negli appunti (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione<
         <translation>Esci</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Ogni richiesta</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Posizione specificata</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Seleziona un percorso di salvataggio</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Cambia il percorso di salvataggio</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione<
         <translation>Apri cartella</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Ogni richiesta</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Posizione specificata</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Seleziona una posizione di salvataggio</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Aggiorna la posizione di salvataggio</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -402,7 +451,7 @@ o utilizza nuovamente la scorciatoia da tastiera per terminare la registrazione<
     <name>ShotStartRecordPlugin</name>
     <message>
         <source>Record</source>
-            <translation>Registrazione</translation>
+        <translation>Registrazione</translation>
     </message>
 </context>
 <context>
@@ -596,14 +645,6 @@ Tieni premuto Maiusc per disegnare una freccia verticale o orizzontale</translat
         <source>Record</source>
         <translation>Registrazione</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Immagini</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Seleziona un percorso di salvataggio</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Cambia il percorso di salvataggio</translation>
@@ -658,14 +699,6 @@ Tieni premuto Maiusc per disegnare quadrati o cerchi.</translation>
         <source>Save to local</source>
         <translation>Salva nella cartella locale</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Salva sul desktop</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Salva nelle immagini</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Salva in %1</translation>
@@ -675,24 +708,12 @@ Tieni premuto Maiusc per disegnare quadrati o cerchi.</translation>
         <translation>Posizione specificata</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Posizione personalizzata</translation>
+        <source>Update the location when saving</source>
+        <translation>Aggiorna la posizione di salvataggio</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Ogni richiesta</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Aggiorna la posizione al salvataggio</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Salva sul desktop</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Salva nelle immagini</translation>
+        <source>Select a location when saving</source>
+        <translation>Seleziona una posizione di salvataggio</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Tieni premuto Maiusc per disegnare quadrati o cerchi.</translation>
         <source>Copy to clipboard (Enter)</source>
         <translation>Copia negli appunti (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
