@@ -25,6 +25,17 @@ or press the shortcut again to stop recording</source>
         <translation>녹화</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>닫기 (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>클립보드에 복사 (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ or press the shortcut again to stop recording</source>
         <translation>종료</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>각 조회</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>지정된 위치</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>저장 시 경로 설정</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>저장 시 경로 변경</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ or press the shortcut again to stop recording</source>
         <translation>폴더 열기</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>각 조회</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>지정된 위치</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>저장 시 위치 선택</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>저장 시 위치 업데이트</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -600,14 +649,6 @@ Shift를 누르고 놓아 수직 또는 수평 화살표를 그립니다</transl
         <source>Record</source>
         <translation>녹화하기</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>사진</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>저장 시 경로 설정</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>저장 시 경로 변경</translation>
@@ -662,14 +703,6 @@ Shift 키를 누른 채로 정사각형이나 원을 그립니다.</translation>
         <source>Save to local</source>
         <translation>로컬에 저장</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>바탕화면에 저장</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>사진에 저장</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>%1에 저장</translation>
@@ -679,24 +712,12 @@ Shift 키를 누른 채로 정사각형이나 원을 그립니다.</translation>
         <translation>지정된 위치</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>사용자 지정 위치</translation>
-    </message>
-    <message>
-        <source>Each inquiry</source>
-        <translation>각 조회</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
+        <source>Update the location when saving</source>
         <translation>저장 시 위치 업데이트</translation>
     </message>
     <message>
-        <source>Save to desktop</source>
-        <translation>바탕화면에 저장</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>사진에 저장</translation>
+        <source>Select a location when saving</source>
+        <translation>저장 시 위치 선택</translation>
     </message>
 </context>
 <context>
@@ -709,6 +730,10 @@ Shift 키를 누른 채로 정사각형이나 원을 그립니다.</translation>
         <source>Copy to clipboard (Enter)</source>
         <translation>클립보드에 복사 (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>확인 (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
