@@ -25,6 +25,17 @@ or press the shortcut again to stop recording</source>
         <translation>ການບັນທຶກ</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>ປິດ (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>ແກ້ວລົງໃນຄຳຕອບ (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ or press the shortcut again to stop recording</source>
         <translation>ອອກ</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>ການສອບສວນທຸກຄັ້ງ</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>ສະຖານທີ່ທີ່ກຳນົດ</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>ຕັ້ງທິດທາງເມື່ອບັນທຶກ</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>ປ່ຽນທິດທາງເມື່ອບັນທຶກ</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ or press the shortcut again to stop recording</source>
         <translation>ເປີດຟ້ອນ</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>ການສອບສວນທຸກຄັ້ງ</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>ສະຖານທີ່ທີ່ກຳນົດ</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>ເລືອກສະຖານທີ່ເມື່ອບັນທຶກ</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>ປັບແຕ່ງສະຖານທີ່ເມື່ອບັນທຶກ</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -445,10 +494,6 @@ Press and hold Shift to draw a straight line</source>
         <source>Options</source>
         <translation>ຕົວເລືອກ</translation>
     </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>ຕັ້ງທິດທາງເມື່ອບັນທຶກ</translation>
-    </message>
     <message>
         <source>Save to</source>
         <translation>ບັນທຶກໄປທີ່</translation>
@@ -457,10 +502,6 @@ Press and hold Shift to draw a straight line</source>
         <source>Desktop</source>
         <translation>ພາບຫນ້າທີ່ສະແດງ</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>ພາບຫນ້າທີ່ສະແດງ</translation>
-    </message>
     <message>
         <source>Format</source>
         <translation>ຮູບແບບ</translation>
@@ -655,14 +696,6 @@ Hold down Shift to draw squares or circles.</source>
         <source>Save to local</source>
         <translation>ບັນທຶກໃນທ້ອງຖິ່ນ</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>ບັນທຶກໃສ່ເດີກັບ</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>ບັນທຶກໃສ່ຮູບຖ່າຍ</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>ບັນທຶກໃສ່ %1</translation>
@@ -672,24 +705,12 @@ Hold down Shift to draw squares or circles.</source>
         <translation>ສະຖານທີ່ທີ່ກຳນົດ</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>ສະຖານທີ່ທີ່ກຳນົດເອົາ</translation>
+        <source>Update the location when saving</source>
+        <translation>ປັບແຕ່ງສະຖານທີ່ເມື່ອບັນທຶກ</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>ການສອບສວນທຸກຄັ້ງ</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>ອັບເດດບ້ານທີ່ບັນທຶກ</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>ບັນທຶກໃສ່ເດີກັດ</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>ບັນທຶກໃສ່ຮູບຖ່າຍ</translation>
+        <source>Select a location when saving</source>
+        <translation>ເລືອກສະຖານທີ່ເມື່ອບັນທຶກ</translation>
     </message>
 </context>
 <context>
@@ -702,6 +723,10 @@ Hold down Shift to draw squares or circles.</source>
         <source>Copy to clipboard (Enter)</source>
         <translation>ແກ້ວລົງໃນຄຳຕອບ (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>ຕອບຖືກຕ້ອງ (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
