@@ -25,6 +25,17 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <translation>Rakaman</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Tutup (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Salin ke papan klip (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <translation>Keluar</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Setiap pertanyaan</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Lokasi Tertentu</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Tetapkan laluan ketika simpan</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Ubah laluan ketika simpan</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ atau klik pintasan sekali lagi untuk hentikan rakaman</translation>
         <translation>Buka Folder</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Setiap pertanyaan</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Lokasi Tertentu</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Tetapkan laluan ketika simpan</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Ubah laluan ketika simpan</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Tekan dan tahan kekunci Shift untuk melukis anak panah menegak atau mengufuk</tr
         <source>Record</source>
         <translation>Rakam</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Gambar</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Tetapkan laluan ketika simpan</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Ubah laluan ketika simpan</translation>
@@ -658,14 +699,6 @@ Tahan Shift untuk melukis segi empat sama atau bulatan.</translation>
         <source>Save to local</source>
         <translation>Simpan ke lokal</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Simpan ke Desktop</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Simpan ke Gambar</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Simpan ke %1</translation>
@@ -675,24 +708,12 @@ Tahan Shift untuk melukis segi empat sama atau bulatan.</translation>
         <translation>Lokasi Tertentu</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Lokasi Pilihan</translation>
+        <source>Update the location when saving</source>
+        <translation>Ubah laluan ketika simpan</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Setiap pertanyaan</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Kemaskini lokasi semasa simpan</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Simpan ke Desktop</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Simpan ke Gambar</translation>
+        <source>Select a location when saving</source>
+        <translation>Tetapkan laluan ketika simpan</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Tahan Shift untuk melukis segi empat sama atau bulatan.</translation>
         <source>Copy to clipboard (Enter)</source>
         <translation>Salin ke papan klip (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
