@@ -25,6 +25,17 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <translation>Opname</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Sluiten (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Kopiëren naar klembord (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <translation>Afsluiten</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Elke vraag</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Specifieke locatie</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Locatie kiezen na klikken op opslaan</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Locatie wijzigen na klikken op opslaan</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ of druk nogmaals op de sneltoets om te stoppen</translation>
         <translation>Map openen</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Elke vraag</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Specifieke locatie</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Locatie kiezen na klikken op opslaan</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Locatie wijzigen na klikken op opslaan</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Houd Shift ingedrukt om een verticale of horizontale pijl te tekenen</translatio
         <source>Record</source>
         <translation>Opnemen</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Afbeeldingen</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Locatie kiezen na klikken op opslaan</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Locatie wijzigen na klikken op opslaan</translation>
@@ -658,14 +699,6 @@ Houd Shift ingedrukt om vierkanten of cirkels te tekenen.</translation>
         <source>Save to local</source>
         <translation>Opslaan naar lokale map</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Opslaan naar bureaublad</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Opslaan naar afbeeldingen</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Opslaan naar %1</translation>
@@ -675,24 +708,12 @@ Houd Shift ingedrukt om vierkanten of cirkels te tekenen.</translation>
         <translation>Specifieke locatie</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Aangepaste locatie</translation>
+        <source>Update the location when saving</source>
+        <translation>Locatie wijzigen na klikken op opslaan</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Elke vraag</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Locatie bijwerken bij opslaan</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Opslaan naar bureaublad</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Opslaan naar afbeeldingen</translation>
+        <source>Select a location when saving</source>
+        <translation>Locatie kiezen na klikken op opslaan</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Houd Shift ingedrukt om vierkanten of cirkels te tekenen.</translation>
         <source>Copy to clipboard (Enter)</source>
         <translation>Kopiëren naar klembord (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
