@@ -25,6 +25,17 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
         <translation>Nagrywanie</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Zamknij (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Skopiuj do schowka (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
         <translation>Wyjdź</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Każde zapytanie</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Określone miejsce</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Ustaw ścieżkę zapisu</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Zmień ścieżkę zapisu</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
         <translation>Otwórz folder</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Każde zapytanie</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Określone miejsce</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Ustaw ścieżkę zapisu</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Zmień ścieżkę zapisu</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Przytrzymaj Shift, aby rysować pionową lub poziomą strzałkę</translation>
         <source>Record</source>
         <translation>Nagrywanie</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Zdjęcia</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Ustaw ścieżkę zapisu</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Zmień ścieżkę zapisu</translation>
@@ -658,14 +699,6 @@ Przytrzymaj Shift, aby narysować kwadraty lub koła.</translation>
         <source>Save to local</source>
         <translation>Zapisz lokalnie</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Zapisz na pulpicie</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Zapisz na zdjęcia</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Zapisz w %1</translation>
@@ -675,24 +708,12 @@ Przytrzymaj Shift, aby narysować kwadraty lub koła.</translation>
         <translation>Określone miejsce</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Niestandardowe miejsce</translation>
+        <source>Update the location when saving</source>
+        <translation>Zmień ścieżkę zapisu</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Każde zapytanie</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Zaktualizuj lokalizację przy zapisie</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Zapisz na pulpicie</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Zapisz na zdjęcia</translation>
+        <source>Select a location when saving</source>
+        <translation>Ustaw ścieżkę zapisu</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Przytrzymaj Shift, aby narysować kwadraty lub koła.</translation>
         <source>Copy to clipboard (Enter)</source>
         <translation>Skopiuj do schowka (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
