@@ -25,6 +25,17 @@ ou pressione novamente o atalho para parar de gravar</translation>
         <translation>Gravação</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Fechar (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Copiar para a área de transferência (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ ou pressione novamente o atalho para parar de gravar</translation>
         <translation>Sair</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Cada consulta</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Localização especificada</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Definir um caminho para salvar</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Alterar o caminho para salvar</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ ou pressione novamente o atalho para parar de gravar</translation>
         <translation>Abrir pasta</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Cada consulta</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Localização especificada</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Selecionar uma localização ao guardar</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Atualizar a localização ao guardar</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Pressionar e manter Shift para desenhar uma seta vertical ou horizontal</transla
         <source>Record</source>
         <translation>Gravar</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Imagens</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Definir um caminho para salvar</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Alterar o caminho para salvar</translation>
@@ -658,14 +699,6 @@ Mantenha pressionada a tecla Shift para desenhar quadrados ou círculos.</transl
         <source>Save to local</source>
         <translation>Salvar localmente</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Salvar no ambiente de trabalho</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Salvar em imagens</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Salvar em %1</translation>
@@ -675,24 +708,12 @@ Mantenha pressionada a tecla Shift para desenhar quadrados ou círculos.</transl
         <translation>Localização especificada</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Localização personalizada</translation>
+        <source>Update the location when saving</source>
+        <translation>Atualizar a localização ao guardar</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Cada consulta</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Atualizar localização ao salvar</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Salvar no ambiente de trabalho</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Salvar em imagens</translation>
+        <source>Select a location when saving</source>
+        <translation>Selecionar uma localização ao guardar</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Mantenha pressionada a tecla Shift para desenhar quadrados ou círculos.</transl
         <source>Copy to clipboard (Enter)</source>
         <translation>Copiar para a área de transferência (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
