@@ -25,6 +25,17 @@ or press the shortcut again to stop recording</source>
         <translation>Запись</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Закрыть (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Скопировать в буфер обмена (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ or press the shortcut again to stop recording</source>
         <translation>Выход</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Каждый запрос</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Указанное место</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Установить путь при сохранении</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Изменить путь при сохранении</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ or press the shortcut again to stop recording</source>
         <translation>Открыть папку</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Каждый запрос</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Указанное место</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Установить путь при сохранении</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Изменить путь при сохранении</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <source>Record</source>
         <translation>Запись</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Изображения</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Установить путь при сохранении</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Изменить путь при сохранении</translation>
@@ -658,14 +699,6 @@ Hold down Shift to draw squares or circles.</source>
         <source>Save to local</source>
         <translation>Сохранить локально</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Сохранить на рабочий стол</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Сохранить в изображения</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Сохранить в %1</translation>
@@ -675,24 +708,12 @@ Hold down Shift to draw squares or circles.</source>
         <translation>Указанное место</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Пользовательское место</translation>
+        <source>Update the location when saving</source>
+        <translation>Изменить путь при сохранении</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Каждый запрос</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Обновить место при сохранении</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Сохранить на рабочий стол</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Сохранить в изображения</translation>
+        <source>Select a location when saving</source>
+        <translation>Установить путь при сохранении</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Hold down Shift to draw squares or circles.</source>
         <source>Copy to clipboard (Enter)</source>
         <translation>Скопировать в буфер обмена (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
