@@ -25,6 +25,17 @@ klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
         <translation>Regjistrim</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Mbylle (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Kopjo te papastër (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
         <translation>Dil</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Cdo pyetje</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Vendndodhje Specifikuar</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Caktoni shteg gjatë ruajtjes</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Ndryshoni shtegun gjatë ruajtjes</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ klikoni ikonën e panelit, ose rishtypni shkurtoren</translation>
         <translation>Hapni Dosje</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Cdo pyetje</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Vendndodhje Specifikuar</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Zgjidhni vendndodhjen gjatë ruajtjes</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Përditësoni vendndodhjen gjatë ruajtjes</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Shtypni dhe mbani të shtypur tastin Shift, që të vizatohet një shigjetë ver
         <source>Record</source>
         <translation>Regjistro</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Foto</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Caktoni shteg gjatë ruajtjes</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Ndryshoni shtegun gjatë ruajtjes</translation>
@@ -658,14 +699,6 @@ Mbani të shtypur tastin Shift që të vizatohet një drejtkëndësh ose një rr
         <source>Save to local</source>
         <translation>Ruaje te lokali</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Ruaje te Desktop</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Ruaje te Foto</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Ruaje te %1</translation>
@@ -675,24 +708,12 @@ Mbani të shtypur tastin Shift që të vizatohet një drejtkëndësh ose një rr
         <translation>Vendndodhje Specifikuar</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Vendndodhje Përzgjedhje</translation>
+        <source>Update the location when saving</source>
+        <translation>Përditësoni vendndodhjen gjatë ruajtjes</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Cdo pyetje</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Përditëso vendndodhjen gjatë ruajtjes</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Ruaje te Desktop</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Ruaje te Foto</translation>
+        <source>Select a location when saving</source>
+        <translation>Zgjidhni vendndodhjen gjatë ruajtjes</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Mbani të shtypur tastin Shift që të vizatohet një drejtkëndësh ose një rr
         <source>Copy to clipboard (Enter)</source>
         <translation>Kopjo te papastër (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK (Enter)</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
