@@ -25,6 +25,17 @@ or press the shortcut again to stop recording</source>
         <translation>Запис</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Затвори (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Копирај у клипборд (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ or press the shortcut again to stop recording</source>
         <translation>Изађи</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Сваки захтев</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Одређено место</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Постави путању приликом сачувања</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Промени путању приликом сачувања</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ or press the shortcut again to stop recording</source>
         <translation>Отвори фолдер</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation type="unfinished">Сваки захтев</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Одређено место</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Постави путању приликом сачувања</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Промени путању приликом сачувања</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <source>Record</source>
         <translation>Снимање</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Слике</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Постави путању приликом сачувања</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Промени путању приликом сачувања</translation>
@@ -658,14 +699,6 @@ Hold down Shift to draw squares or circles.</source>
         <source>Save to local</source>
         <translation>Сачувај на локалном</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Сачувај на радној површини</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Сачувај на слике</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Сачувај у %1</translation>
@@ -675,24 +708,12 @@ Hold down Shift to draw squares or circles.</source>
         <translation>Одређено место</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Прилагођено место</translation>
+        <source>Update the location when saving</source>
+        <translation>Промени путању приликом сачувања</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Сваки захтев</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Ажурирај место при сачувању</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Сачувај на радној површини</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Сачувај на слике</translation>
+        <source>Select a location when saving</source>
+        <translation>Постави путању приликом сачувања</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Hold down Shift to draw squares or circles.</source>
         <source>Copy to clipboard (Enter)</source>
         <translation>Копирај у клипборд (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>ОК Enter</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
