@@ -25,6 +25,17 @@ tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
         <translation>Kaydediyor</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Kapat (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Panoya kopyala (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
         <translation>Çıkış</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Her sorgulama</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Belirtilen Konum</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Kaydet sırasında bir yol ayarla</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Kaydet sırasında yolu değiştir</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
         <translation>Klasör Aç</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation type="unfinished">Her sorgulama</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Belirtilen Konum</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Kaydet sırasında bir yol ayarla</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Kaydet sırasında yolu değiştir</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Dikey veya yatay ok çizmek için Shift tuşunu basılı tutun</translation>
         <source>Record</source>
         <translation>Kayıt</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Resimler</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Kaydet sırasında bir yol ayarla</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Kaydet sırasında yolu değiştir</translation>
@@ -658,14 +699,6 @@ Kare veya daire çizmek için Shift tuşunu basılı tutun.</translation>
         <source>Save to local</source>
         <translation>Yerel olarak kaydet</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Masaüstüne kaydet</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Resimlere kaydet</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>%1&apos;e kaydet</translation>
@@ -675,24 +708,12 @@ Kare veya daire çizmek için Shift tuşunu basılı tutun.</translation>
         <translation>Belirtilen Konum</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Özel Konum</translation>
+        <source>Update the location when saving</source>
+        <translation>Kaydet sırasında yolu değiştir</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Her sorgulama</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Kaydet sırasında konumu güncelle</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Masaüstüne kaydet</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Resimlere kaydet</translation>
+        <source>Select a location when saving</source>
+        <translation>Kaydet sırasında bir yol ayarla</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Kare veya daire çizmek için Shift tuşunu basılı tutun.</translation>
         <source>Copy to clipboard (Enter)</source>
         <translation>Panoya kopyala (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>Tamam Enter</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
