@@ -24,6 +24,17 @@ or press the shortcut again to stop recording</source>
         <translation>ئېكراننى سىنغا ئېلىش</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>تاقاش (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>پاستەر ساقلاش (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -122,6 +133,25 @@ or press the shortcut again to stop recording</source>
         <translation>چېكىنىش</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>ھەر قورال</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>بىرلىك ھەرپ</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>ئورۇننى ساقلىغاندا يېڭىلاش</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>ئورۇننى ساقلىغاندا تەڭشەش</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -174,6 +204,25 @@ or press the shortcut again to stop recording</source>
         <translation>ھۆججەت قىسقۇچنى ئېچىش</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>ھەر قورال</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>بىرلىك ھەرپ</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>ئورۇننى ساقلىغاندا يېڭىلاش</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>ئورۇننى ساقلىغاندا تەڭشەش</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -595,14 +644,6 @@ Shift نى بېسىپ تۇرسىڭىز تىك ۋە توغرىسىغا تۈز ك
         <source>Record</source>
         <translation>سىنغا ئېلىش</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>رەسىم</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>ئورۇننى ساقلىغاندا يېڭىلاش</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>ئورۇننى ساقلىغاندا تەڭشەش</translation>
@@ -657,14 +698,6 @@ Hold down Shift to draw squares or circles.</source>
         <source>Save to local</source>
         <translation>لوكال ساقلاش</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>ئۈستەليۈز ساقلاش</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>رەسىم ساقلاش</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>%1 ساقلاش</translation>
@@ -674,24 +707,12 @@ Hold down Shift to draw squares or circles.</source>
         <translation>بىرلىك ھەرپ</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>ئاددىيەتلىك ھەرپ</translation>
+        <source>Update the location when saving</source>
+        <translation>ئورۇننى ساقلىغاندا تەڭشەش</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>ھەر قورال</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>ساقلىغاندا ھەرپنى ئەڭگە قىلىش</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>ئۈستەليۈز ساقلاش</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>رەسىم ساقلاش</translation>
+        <source>Select a location when saving</source>
+        <translation>ئورۇننى ساقلىغاندا يېڭىلاش</translation>
     </message>
 </context>
 <context>
@@ -704,6 +725,10 @@ Hold down Shift to draw squares or circles.</source>
         <source>Copy to clipboard (Enter)</source>
         <translation>پاستەر ساقلاش (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>موافق Enter</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
