@@ -25,6 +25,17 @@ or press the shortcut again to stop recording</source>
         <translation>Записування</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>Закрити (Esc)</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>Скопіювати до буфера обміну (Enter)</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ or press the shortcut again to stop recording</source>
         <translation>Вийти</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Кожне запитування</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>Вказане місце</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>Встановити шлях для збереження</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>Змінити шлях для збереження</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ or press the shortcut again to stop recording</source>
         <translation>Відкрити теку</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>Кожне запитування</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>Вказане місце</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>Виберіть місце для збереження</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>Оновити місце для збереження</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <source>Record</source>
         <translation>Записати</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>Зображення</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>Встановити шлях для збереження</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>Змінити шлях для збереження</translation>
@@ -658,14 +699,6 @@ Hold down Shift to draw squares or circles.</source>
         <source>Save to local</source>
         <translation>Зберегти локально</translation>
     </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>Зберегти на стільниці</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>Зберегти в зображення</translation>
-    </message>
     <message>
         <source>Save to %1</source>
         <translation>Зберегти до %1</translation>
@@ -675,24 +708,12 @@ Hold down Shift to draw squares or circles.</source>
         <translation>Вказане місце</translation>
     </message>
     <message>
-        <source>Custom Location</source>
-        <translation>Власний шлях</translation>
+        <source>Update the location when saving</source>
+        <translation>Оновити місце для збереження</translation>
     </message>
     <message>
-        <source>Each inquiry</source>
-        <translation>Кожне запитування</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>Оновлення місця збереження</translation>
-    </message>
-    <message>
-        <source>Save to desktop</source>
-        <translation>Зберегти на стільниці</translation>
-    </message>
-    <message>
-        <source>Save to pictures</source>
-        <translation>Зберегти в зображення</translation>
+        <source>Select a location when saving</source>
+        <translation>Виберіть місце для збереження</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Hold down Shift to draw squares or circles.</source>
         <source>Copy to clipboard (Enter)</source>
         <translation>Скопіювати до буфера обміну (Enter)</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>OK Enter</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
