@@ -25,6 +25,17 @@ or press the shortcut again to stop recording</source>
         <translation>录屏</translation>
     </message>
 </context>
+<context>
+    <name>MainToolWidget</name>
+    <message>
+        <source>Close (Esc)</source>
+        <translation>关闭 Esc</translation>
+    </message>
+    <message>
+        <source>Copy to clipboard (Enter)</source>
+        <translation>复制到剪贴板</translation>
+    </message>
+</context>
 <context>
     <name>MainWindow</name>
     <message>
@@ -123,6 +134,25 @@ or press the shortcut again to stop recording</source>
         <translation>退出</translation>
     </message>
 </context>
+<context>
+    <name>PinSaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>每次询问</translation>
+    </message>
+    <message>
+        <source>Specified Location</source>
+        <translation>指定位置</translation>
+    </message>
+    <message>
+        <source>Set a path on save</source>
+        <translation>保存时设置位置</translation>
+    </message>
+    <message>
+        <source>Change the path on save</source>
+        <translation>保存时更新位置</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -175,6 +205,25 @@ or press the shortcut again to stop recording</source>
         <translation>打开文件夹</translation>
     </message>
 </context>
+<context>
+    <name>SaveMenuManager</name>
+    <message>
+        <source>Each inquiry</source>
+        <translation>每次询问</translation>
+    </message>
+    <message>
+        <source>Specified location</source>
+        <translation>指定位置</translation>
+    </message>
+    <message>
+        <source>Select a location when saving</source>
+        <translation>保存时选择位置</translation>
+    </message>
+    <message>
+        <source>Update the location when saving</source>
+        <translation>保存时更新位置</translation>
+    </message>
+</context>
 <context>
     <name>Screenshot</name>
     <message>
@@ -596,14 +645,6 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <source>Record</source>
         <translation>录屏</translation>
     </message>
-    <message>
-        <source>Pictures</source>
-        <translation>图片</translation>
-    </message>
-    <message>
-        <source>Set a path on save</source>
-        <translation>保存时设置位置</translation>
-    </message>
     <message>
         <source>Change the path on save</source>
         <translation>保存时更新位置</translation>
@@ -656,18 +697,6 @@ Press and hold Shift to draw a vertical or horizontal arrow</source>
         <source>Specified Location</source>
         <translation>指定位置</translation>
     </message>
-    <message>
-        <source>Custom Location</source>
-        <translation>自定义位置</translation>
-    </message>
-    <message>
-        <source>Each inquiry</source>
-        <translation>每次询问</translation>
-    </message>
-    <message>
-        <source>Update location on save</source>
-        <translation>保存时更新位置</translation>
-    </message>
     <message>
         <source>Geometric Tools (R)
 Hold down Shift to draw squares or circles.</source>
@@ -679,20 +708,12 @@ Hold down Shift to draw squares or circles.</source>
         <translation>保存到%1</translation>
     </message>
     <message>
-        <source>Save to desktop</source>
-        <translation>保存到桌面</translation>
+        <source>Update the location when saving</source>
+        <translation>保存时更新位置</translation>
     </message>
     <message>
-        <source>Save to pictures</source>
-        <translation>保存到图片</translation>
-    </message>
-    <message>
-        <source>Save to Desktop</source>
-        <translation>保存到桌面</translation>
-    </message>
-    <message>
-        <source>Save to Pictures</source>
-        <translation>保存到图片</translation>
+        <source>Select a location when saving</source>
+        <translation>保存时选择位置</translation>
     </message>
 </context>
 <context>
@@ -705,6 +726,10 @@ Hold down Shift to draw squares or circles.</source>
         <source>Copy to clipboard (Enter)</source>
         <translation>复制到剪贴板</translation>
     </message>
+    <message>
+        <source>OK (Enter)</source>
+        <translation>确认 Enter</translation>
+    </message>
 </context>
 <context>
     <name>TopTips</name>
